@@ -1,8 +1,12 @@
 package SecondTestApp::Cmd::ifc;
 
-use Moo;
+BEGIN {
+    my $moodel = $ENV{WHICH_MOODEL} || "Moo";
+    eval "use $moodel;"; $@ and die $@;
+    $moodel->import;
 
-BEGIN { with "MooX::Cmd::Role"; }
+    __PACKAGE__->can("with")->("MooX::Cmd::Role");
+}
 
 around _build_command_execute_method_name => sub { "run" };
 
